@@ -145,7 +145,6 @@ class ComplexConv2d(nn.Module):
 
     def forward(self, x):
         weight, bias = map(torch.view_as_complex, (self.weight, self.bias))
-        print(x.dtype, weight.dtype, x.device, weight.device)
         return F.conv2d(x, weight, bias, stride = self.stride, padding = self.padding)
 
 def ComplexSTFTResidualUnit(chan_in, chan_out, strides):
@@ -331,7 +330,7 @@ class LocalTransformerBlock(nn.Module):
         **kwargs
     ):
         super().__init__()
-        self.attn = LocalMHA(dim = dim, **kwargs)
+        self.attn = LocalMHA(dim = dim, qk_rmsnorm = True, **kwargs)
         self.ff = FeedForward(dim = dim)
 
     def forward(self, x):
